@@ -2,6 +2,8 @@
 
 from __future__ import annotations
 
+import asyncio
+import logging
 import os
 from typing import Any
 
@@ -137,8 +139,9 @@ class LinearAdapter(BaseAdapter[Task]):
             # Load team data and workflow states concurrently
             team_id = await self._ensure_team_id()
 
-            # Load workflow states for the team
+            # Load workflow states and labels for the team
             await self._load_workflow_states(team_id)
+            await self._load_team_labels(team_id)
 
             self._initialized = True
 
@@ -204,7 +207,7 @@ class LinearAdapter(BaseAdapter[Task]):
             )
 
             workflow_states = {}
-            for state in result["workflowStates"]["nodes"]:
+            for state in result["team"]["states"]["nodes"]:
                 state_type = state["type"].lower()
                 if state_type not in workflow_states:
                     workflow_states[state_type] = state
@@ -216,6 +219,113 @@ class LinearAdapter(BaseAdapter[Task]):
         except Exception as e:
             raise ValueError(f"Failed to load workflow states: {e}")
 
+    async def _load_team_labels(self, team_id: str) -> None:
+        """Load and cache labels for the team with retry logic.
+
+        Args:
+            team_id: Linear team ID
+
+        """
+        logger = logging.getLogger(__name__)
+
+        query = """
+            query GetTeamLabels($teamId: String!) {
+                team(id: $teamId) {
+                    labels {
+                        nodes {
+                            id
+                            name
+                            color
+                            description
+                        }
+                    }
+                }
+            }
+        """
+
+        max_retries = 3
+        for attempt in range(max_retries):
+            try:
+                result = await self.client.execute_query(query, {"teamId": team_id})
+                labels = result.get("team", {}).get("labels", {}).get("nodes", [])
+                self._labels_cache = labels
+                logger.info(f"Loaded {len(labels)} labels for team {team_id}")
+                return  # Success
+
+            except Exception as e:
+                if attempt < max_retries - 1:
+                    wait_time = 2**attempt
+                    logger.warning(
+                        f"Failed to load labels (attempt {attempt + 1}/{max_retries}): {e}. "
+                        f"Retrying in {wait_time}s..."
+                    )
+                    await asyncio.sleep(wait_time)
+                else:
+                    logger.error(
+                        f"Failed to load team labels after {max_retries} attempts: {e}",
+                        exc_info=True,
+                    )
+                    self._labels_cache = []  # Explicitly empty on failure
+
+    async def _resolve_label_ids(self, label_names: list[str]) -> list[str]:
+        """Resolve label names to Linear label IDs with proper None vs empty list handling.
+
+        Args:
+            label_names: List of label names
+
+        Returns:
+            List of Linear label IDs that exist
+
+        """
+        logger = logging.getLogger(__name__)
+
+        # None = not loaded yet, [] = loaded but empty or failed
+        if self._labels_cache is None:
+            team_id = await self._ensure_team_id()
+            await self._load_team_labels(team_id)
+
+        if self._labels_cache is None:
+            # Still None after load attempt - should not happen
+            logger.error(
+                "Label cache is None after load attempt. Tags will be skipped."
+            )
+            return []
+
+        if not self._labels_cache:
+            # Empty list - either no labels in team or load failed
+            logger.warning(
+                f"Team has no labels available. Cannot resolve tags: {label_names}"
+            )
+            return []
+
+        # Create name -> ID mapping (case-insensitive)
+        label_map = {label["name"].lower(): label["id"] for label in self._labels_cache}
+
+        logger.debug(f"Available labels in team: {list(label_map.keys())}")
+
+        # Resolve label names to IDs
+        label_ids = []
+        unmatched_labels = []
+
+        for name in label_names:
+            label_id = label_map.get(name.lower())
+            if label_id:
+                label_ids.append(label_id)
+                logger.debug(f"Resolved label '{name}' to ID: {label_id}")
+            else:
+                unmatched_labels.append(name)
+                logger.warning(
+                    f"Label '{name}' not found in team. Available labels: {list(label_map.keys())}"
+                )
+
+        if unmatched_labels:
+            logger.warning(
+                f"Could not resolve labels: {unmatched_labels}. "
+                f"Create them in Linear first or check spelling."
+            )
+
+        return label_ids
+
     def _get_state_mapping(self) -> dict[TicketState, str]:
         """Get mapping from universal states to Linear workflow state IDs.
 
@@ -311,12 +421,28 @@ class LinearAdapter(BaseAdapter[Task]):
         # Build issue input using mapper
         issue_input = build_linear_issue_input(task, team_id)
 
+        # Set default state if not provided
+        # Map OPEN to "unstarted" state (typically "To-Do" in Linear)
+        if task.state == TicketState.OPEN and self._workflow_states:
+            state_mapping = self._get_state_mapping()
+            if TicketState.OPEN in state_mapping:
+                issue_input["stateId"] = state_mapping[TicketState.OPEN]
+
         # Resolve assignee to user ID if provided
         if task.assignee:
             user_id = await self._get_user_id(task.assignee)
             if user_id:
                 issue_input["assigneeId"] = user_id
 
+        # Resolve label names to IDs if provided
+        if task.tags:
+            label_ids = await self._resolve_label_ids(task.tags)
+            if label_ids:
+                issue_input["labelIds"] = label_ids
+            else:
+                # Remove labelIds if no labels resolved
+                issue_input.pop("labelIds", None)
+
         try:
             result = await self.client.execute_mutation(
                 CREATE_ISSUE_MUTATION, {"input": issue_input}
@@ -489,6 +615,12 @@ class LinearAdapter(BaseAdapter[Task]):
                 if user_id:
                     update_input["assigneeId"] = user_id
 
+            # Resolve label names to IDs if provided
+            if "tags" in updates and updates["tags"]:
+                label_ids = await self._resolve_label_ids(updates["tags"])
+                if label_ids:
+                    update_input["labelIds"] = label_ids
+
             # Execute update
             result = await self.client.execute_mutation(
                 UPDATE_ISSUE_MUTATION, {"id": linear_id, "input": update_input}
@@ -733,7 +865,7 @@ class LinearAdapter(BaseAdapter[Task]):
 
             comment_input = {
                 "issueId": linear_id,
-                "body": comment.body,
+                "body": comment.content,
             }
 
             result = await self.client.execute_mutation(
