@@ -225,14 +225,16 @@ ISSUE_LIST_FRAGMENTS = (
 # Query definitions
 
 WORKFLOW_STATES_QUERY = """
-    query WorkflowStates($teamId: ID!) {
-        workflowStates(filter: { team: { id: { eq: $teamId } } }) {
-            nodes {
-                id
-                name
-                type
-                position
-                color
+    query WorkflowStates($teamId: String!) {
+        team(id: $teamId) {
+            states {
+                nodes {
+                    id
+                    name
+                    type
+                    position
+                    color
+                }
             }
         }
     }
