@@ -2,13 +2,12 @@
 
 from __future__ import annotations
 
-from typing import Any, Optional
-from unittest.mock import AsyncMock, Mock
+from typing import Any
 
 import pytest
 
 from mcp_ticketer.core.adapter import BaseAdapter
-from mcp_ticketer.core.models import Task, Epic, Comment, SearchQuery, TicketState
+from mcp_ticketer.core.models import Comment, SearchQuery, Task, TicketState
 
 
 class MockAdapter(BaseAdapter[Task]):
@@ -42,11 +41,11 @@ class MockAdapter(BaseAdapter[Task]):
         self.tickets_db[ticket.id] = ticket
         return ticket
 
-    async def read(self, ticket_id: str) -> Optional[Task]:
+    async def read(self, ticket_id: str) -> Task | None:
         """Read a ticket."""
         return self.tickets_db.get(ticket_id)
 
-    async def update(self, ticket_id: str, updates: dict[str, Any]) -> Optional[Task]:
+    async def update(self, ticket_id: str, updates: dict[str, Any]) -> Task | None:
         """Update a ticket."""
         ticket = self.tickets_db.get(ticket_id)
         if not ticket:
@@ -69,7 +68,7 @@ class MockAdapter(BaseAdapter[Task]):
         self,
         limit: int = 10,
         offset: int = 0,
-        filters: Optional[dict[str, Any]] = None,
+        filters: dict[str, Any] | None = None,
     ) -> list[Task]:
         """List tickets."""
         tickets = list(self.tickets_db.values())
@@ -101,7 +100,7 @@ class MockAdapter(BaseAdapter[Task]):
 
     async def transition_state(
         self, ticket_id: str, target_state: TicketState
-    ) -> Optional[Task]:
+    ) -> Task | None:
         """Transition state."""
         if not await self.validate_transition(ticket_id, target_state):
             return None
@@ -110,7 +109,9 @@ class MockAdapter(BaseAdapter[Task]):
     async def add_comment(self, comment: Comment) -> Comment:
         """Add comment."""
         if not comment.id:
-            comment.id = f"COMMENT-{len(self.comments_db.get(comment.ticket_id, [])) + 1}"
+            comment.id = (
+                f"COMMENT-{len(self.comments_db.get(comment.ticket_id, [])) + 1}"
+            )
 
         if comment.ticket_id not in self.comments_db:
             self.comments_db[comment.ticket_id] = []
@@ -142,7 +143,9 @@ def mock_adapter(mock_adapter_config: dict[str, Any]) -> MockAdapter:
 class TestBaseAdapterInit:
     """Tests for BaseAdapter initialization."""
 
-    def test_adapter_init_with_config(self, mock_adapter_config: dict[str, Any]) -> None:
+    def test_adapter_init_with_config(
+        self, mock_adapter_config: dict[str, Any]
+    ) -> None:
         """Test adapter initialization with configuration."""
         adapter = MockAdapter(mock_adapter_config)
         assert adapter.config == mock_adapter_config
@@ -206,7 +209,9 @@ class TestValidateTransition:
 
         # OPEN -> TESTED is invalid (must go through IN_PROGRESS -> READY -> TESTED)
         assert created.id is not None
-        is_valid = await mock_adapter.validate_transition(created.id, TicketState.TESTED)
+        is_valid = await mock_adapter.validate_transition(
+            created.id, TicketState.TESTED
+        )
         assert is_valid is False
 
     @pytest.mark.asyncio
